Praxis Seizure II: Austin Austin, Texas February 20th 1999 8 players R. Brian Smith https://groups.google.com/d/topic/rec.games.trading-cards.jyhad/79Jk2Un-6hI/discussion R. Brian Smith's Victorious Ventrue/!Ventrue Deck follows: Crypt (14 cards, min=13, max=37, avg=5.93) ------------------------------------------ 2x Arika 11 DOM FOR OBF PRE aus cel inner circle Ventrue:2 2x Ranjan Rishi, Camarilla Scholar 5 DOM PRE for Ventrue:2 1x Emerson Bridges 8 DOM FOR PRE pot prince Ventrue:1 1x Sir Walter Nash 7 DOM FOR PRE prince Ventrue:1 1x Timothy Crowley 7 FOR PRE ani dom prince Ventrue:1 1x Vanessa 6 DOM FOR aus pre Ventrue antitribu:2 1x Jazz Wentworth 5 PRE dom for Ventrue:1 1x Melissa Barton 5 cel dom for pre Ventrue:1 1x Ingrid Russo 4 DOM for Ventrue antitribu:2 1x Violette Prentiss 4 PRE dom Ventrue:1 1x Gideon Fontaine 3 PRE Ventrue:1 1x Samson 2 dom Ventrue antitribu:2 Library (85 cards) Master (18) 1x Anarch Troublemaker 4x Blood Doll 1x Corporate Hunting Ground 2x Dominate 1x Dreams of the Sphinx 1x Hostile Takeover 2x Minion Tap 2x Misdirection 2x Pentex(TM) Subversion 1x Presence 1x Uptown Hunting Ground Action (26) 1x Dominate Kine 2x Fifth Tradition: Hospitality 2x Force of Will 6x Govern the Unaligned 2x Legal Manipulations 3x Mind Numb 2x Propaganda 3x Restoration 2x Slaughtering the Herd 3x Social Charm Retainer (1) 1x Marijava Ghoul Action Modifier (21) 5x Bonding 2x Conditioning 3x Daring the Dawn 2x Day Operation 2x Foreshadowing Destruction 2x Freak Drive 4x Seduction 1x Sleeping Mind, The Reaction (12) 4x Deflection 3x Forced Awakening 1x Obedience 2x Second Tradition: Domain 2x Wake with Evening's Freshness Combat (7) 1x Majesty 2x Skin of Rock 1x Skin of Steel 2x Superior Mettle 1x Unflinching Persistence